@import url("resource:///org/gnome/gnome-flashback/theme/common.css");

gf-popup-window {
  background-color: #e8e8e7;
  color: #2e3436;
  border: 1px solid rgba(0, 0, 0, 0.23);
}

gf-popup-window.solid {
  border: 1px solid #a5a5a1;
}

#gf-candidate-popup gf-candidate-box:selected,
#gf-candidate-popup gf-candidate-box:hover {
  background-color: #4a90d9;
  color: #ffffff;
}

#gf-input-source-popup #gf-input-source:selected {
  background-color: #4a90d9;
  color: #ffffff;
}

#gf-osd-window levelbar block.overdrive {
  background-color: #e01b24;
  border-color: #e01b24;
}

gf-icon label {
  color: #ffffff;
}

gf-icon:selected label {
  background: #4a90d9;
  color: #ffffff;
}
