
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef GF_DESKTOP_ENUM_TYPES_H
#define GF_DESKTOP_ENUM_TYPES_H

#include <glib-object.h>

G_BEGIN_DECLS
GType gf_icon_size_get_type (void) G_GNUC_CONST;
#define GF_TYPE_ICON_SIZE (gf_icon_size_get_type())
GType gf_placement_get_type (void) G_GNUC_CONST;
#define GF_TYPE_PLACEMENT (gf_placement_get_type())
GType gf_sort_by_get_type (void) G_GNUC_CONST;
#define GF_TYPE_SORT_BY (gf_sort_by_get_type())
G_END_DECLS

#endif

/* Generated data ends here */

